==> scpdb-1.1.0.tgz: package/app/models/ban-record.ts <==
import db from '../core/db';
import ApplicationModel from './application-model';
import {IsDateString, IsNumber, IsOptional, IsString, Length, Matches} from 'class-validator';
import {plainToClass} from 'class-transformer';

export default class BanRecord extends ApplicationModel {

    @IsNumber()
    addedBy: number | null;

    @IsString()
    @Matches(/^\d{18}$/)
    accusedDiscordId: string;

    @IsOptional()
    @IsString()
    accusedDiscordUsername?: string;

    @IsOptional()
    @IsString()
    @Length(2, 1000)
    caseDescription?: string;

    @IsOptional()
    @IsString()
    @Length(2, 20)
    caseModerator?: string;

    @IsString()
    @Length(2, 100)
    caseOrigin: string;

    @IsOptional()
    @IsDateString()
    bannedUntil?: Date;

    static new(data: any) {
        return plainToClass(BanRecord, data);
    }

    static getAll() {
        // TODO Maybe should have everything in camelCase for consistency
        return db.many(`
            SELECT
                uuid,
                accused_discord_id as "accusedDiscordId",
                accused_discord_username as "accusedDiscordUsername",
                added_by as "addedBy",
                case_description as "caseDescription",
                case_moderator as "caseModerator",
                case_origin as "caseOrigin",
                banned_until as "bannedUntil"
            FROM int_ban_records
            ORDER BY id ASC;
        `);
    }

    async save() {
        const errors = await this.validate();
        if (errors.length) {
            throw new Error('Record validation failed');
        }

        // TODO Use ColumnSet here
        return db.query(`
            INSERT INTO int_ban_records (
                accused_discord_id,
                accused_discord_username,
                added_by,
                case_description,
                case_moderator,
                case_origin,
                banned_until
            ) VALUES (
                $(accusedDiscordId),
                $(accusedDiscordUsername),
                $(addedBy),
                $(caseDescription),
                $(caseModerator),
                $(caseOrigin),
                $(bannedUntil)
            );
        `, Object.assign(
            {},
            {
                accusedDiscordUsername: null,
                caseDescription: null,
                caseModerator: null,
                bannedUntil: null
            },
            this
        ));
    }
}

==> scpdb-1.3.0.tgz: package/app/models/ban-record.ts <==
import db from '../core/db';
import ApplicationRecord from './application-record';
import {IsDateString, IsNumber, IsOptional, IsString, Length, Matches} from 'class-validator';
import {plainToClass} from 'class-transformer';

export default class BanRecord extends ApplicationRecord {

    @IsNumber()
    addedBy: number | null;

    @IsString()
    @Matches(/^\d{18}$/)
    accusedDiscordId: string;

    @IsOptional()
    @IsString()
    accusedDiscordUsername?: string;

    @IsOptional()
    @IsString()
    @Length(2, 1000)
    caseDescription?: string;

    @IsOptional()
    @IsString()
    @Length(2, 20)
    caseModerator?: string;

    @IsString()
    @Length(2, 100)
    caseOrigin: string;

    @IsOptional()
    @IsDateString()
    bannedUntil?: Date;

    static new(data: any) {
        return plainToClass(BanRecord, [data])[0];
    }

    static getAll() {
        // TODO Maybe should have everything in camelCase for consistency
        return db.many(`
            SELECT
                uuid,
                accused_discord_id as "accusedDiscordId",
                accused_discord_username as "accusedDiscordUsername",
                added_by as "addedBy",
                case_description as "caseDescription",
                case_moderator as "caseModerator",
                case_origin as "caseOrigin",
                banned_until as "bannedUntil"
            FROM int_ban_records
            ORDER BY id ASC;
        `);
    }

    async save() {
        const errors = await this.validate();
        if (errors.length) {
            throw new Error('Record validation failed');
        }

        // TODO Use ColumnSet here
        return db.one(`
            INSERT INTO int_ban_records (
                accused_discord_id,
                accused_discord_username,
                added_by,
                case_description,
                case_moderator,
                case_origin,
                banned_until
            ) VALUES (
                $(accusedDiscordId),
                $(accusedDiscordUsername),
                $(addedBy),
                $(caseDescription),
                $(caseModerator),
                $(caseOrigin),
                $(bannedUntil)
            ) RETURNING uuid;
        `, Object.assign(
            {},
            {
                accusedDiscordUsername: null,
                caseDescription: null,
                caseModerator: null,
                bannedUntil: null
            },
            this
        ));
    }
}
